==> libktorrent_2.2.0.orig.tar.xz: libktorrent-2.2.0/src/interfaces/queuemanagerinterface.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include "queuemanagerinterface.h"

namespace bt
{
	bool QueueManagerInterface::qm_enabled = true;

	QueueManagerInterface::QueueManagerInterface()
	{}


	QueueManagerInterface::~QueueManagerInterface()
	{}

	void QueueManagerInterface::setQueueManagerEnabled(bool on)
	{
		qm_enabled = on;
	}

}

==> libktorrent-20.12.3.tar.xz: libktorrent-20.12.3/src/interfaces/queuemanagerinterface.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include "queuemanagerinterface.h"
#include <torrent/torrentcontrol.h>

namespace bt
{
bool QueueManagerInterface::qm_enabled = true;

QueueManagerInterface::QueueManagerInterface()
{}


QueueManagerInterface::~QueueManagerInterface()
{}

void QueueManagerInterface::setQueueManagerEnabled(bool on)
{
    qm_enabled = on;
}

bool QueueManagerInterface::permitStatsSync(TorrentControl *tc)
{
    return tc->getStatsSyncElapsedTime() >= 5 * 60 * 1000; // 5 sec
}

}
